cytoflow.views package
======================

Submodules
----------

cytoflow.views.bar_chart module
-------------------------------

.. automodule:: cytoflow.views.bar_chart
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.histogram module
-------------------------------

.. automodule:: cytoflow.views.histogram
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.histogram_2d module
----------------------------------

.. automodule:: cytoflow.views.histogram_2d
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.i_selectionview module
-------------------------------------

.. automodule:: cytoflow.views.i_selectionview
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.i_view module
----------------------------

.. automodule:: cytoflow.views.i_view
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.kde_1d module
----------------------------

.. automodule:: cytoflow.views.kde_1d
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.kde_2d module
----------------------------

.. automodule:: cytoflow.views.kde_2d
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.scatterplot module
---------------------------------

.. automodule:: cytoflow.views.scatterplot
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.stats_1d module
------------------------------

.. automodule:: cytoflow.views.stats_1d
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.stats_2d module
------------------------------

.. automodule:: cytoflow.views.stats_2d
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.table module
---------------------------

.. automodule:: cytoflow.views.table
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.test module
--------------------------

.. automodule:: cytoflow.views.test
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.violin module
----------------------------

.. automodule:: cytoflow.views.violin
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflow.views
    :members:
    :undoc-members:
    :show-inheritance:
